@@ -291,7 +291,8 @@ escchr:
 			while (1) {
 				c = GETNEXT();
 				if (c == EOF ||
-				    !c || !strchr("0123456789eE+-.", c) ||
+				    (!isdigit(c) && c != 'e' && c != 'E' &&
+				     c != '+' && c != '-' && c != '.') ||
 				    p + 1 >= sizeof(pri)) {
 					pri[p] = '\0';
 					cb(nodes, depth + 1, pri);
